==> library1.4.1.tar.bz2: library/about.php <==
<!DOCTYPE html>
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////
  require_once "utils/chlang_osn.php";

  require_once "config.php";
  $titlepage=$TEXT['maker-title'];
?>
<html>
<head>
<meta http-equiv="Expires" content="Mon, 23 May 1995 02:00:00 GMT" />
<meta http-equiv="Cache-Control" content="no-cache, must-revalidate" />
<meta charset="utf-8" />
<meta name="description" content="<?php echo $description; ?>" />
<meta name="keywords" content="<?php echo $keywords; ?>" />
<title><?php echo $TEXT['maker-title']; ?></title>
<link rel="StyleSheet" type="text/css" href="skins/base/reader.css" />
<link rel="icon" href="favicon.ico" type="image/x-icon" />
<link rel="shortcut icon" href="favicon.ico" type="image/x-icon" />
</head>
<body text=#000000 bgColor=#cccccc onload="window.status='<?php echo $TEXT['maker8']; ?>'">
<h1><?php echo $TEXT['maker-title']; ?></h1><hr/>
<table class="clock" border="0" cellpadding="3" cellspacing="0" width="100%">
  <tr align=left><td><?php echo $TEXT['maker1']; ?></td>
  <tr align=left>
    <td><?php echo $TEXT['maker2']; ?>
      <br/><?php echo $TEXT['maker3']; ?>
      <br/><?php echo $TEXT['maker4']; ?>
      <br/><?php echo $TEXT['maker5']; ?>
      <br/><?php echo $TEXT['maker6']; ?>
    </td>
  <tr align=left>
    <td><hr/>
      <?php echo $TEXT['maker7']; ?>
      <br/><a href="http://tel-spr.narod.ru/library" target=_blank title="<?php echo $TEXT['global-title']; ?>">http://tel-spr.narod.ru</a>
    </td>
  </tr>
  <tr align=right>
    <td><?php echo $TEXT['maker8']; ?></td>
  </tr>
</table>
</body>
</html>

==> library1.19.1.tar.bz2: library/about.php <==
<!DOCTYPE html>
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////
  require_once "utils/chlang_osn.php";

  require_once "config.php";
  $titlepage=$TEXT['maker-title'];
?>
<html>
<head>
<meta http-equiv="Expires" content="Mon, 23 May 1995 02:00:00 GMT" />
<meta http-equiv="Cache-Control" content="no-cache, must-revalidate" />
<meta charset="utf-8" />
<meta name="description" content="<?php echo $description; ?>" />
<meta name="keywords" content="<?php echo $keywords; ?>" />
<title><?php echo $TEXT['maker-title']; ?></title>
<link rel="StyleSheet" type="text/css" href="skins/base/reader.css" />
<link rel="icon" href="favicon.ico" type="image/x-icon" />
<link rel="shortcut icon" href="favicon.ico" type="image/x-icon" />
</head>
<body text=#000000 bgColor=#cccccc onload="window.status='<?php echo $TEXT['maker8']; ?>'">
<h1><?php echo $TEXT['maker-title']; ?></h1><hr/>
<table class="clock" border="0" cellpadding="3" cellspacing="0" width="100%">
  <tr align="left"><td><?php echo $TEXT['maker1']; ?></td>
  <tr align="left">
    <td><?php echo $TEXT['maker2']; ?>
      <br/><?php echo $TEXT['maker3']; ?>
      <br/><?php echo $TEXT['maker4']; ?>
      <br/><?php echo $TEXT['maker5']; ?>
      <br/><?php echo $TEXT['maker6']; ?>
    </td>
  <tr align="left">
    <td><hr/>
      <?php echo $TEXT['maker7']; ?>
      <br/><a href="http://tel-spr.narod.ru/library" target=_blank title="<?php echo $TEXT['global-title']; ?>">http://tel-spr.narod.ru</a>
    </td>
  </tr>
  <tr align="right">
    <td><?php echo $TEXT['maker8']; ?></td>
  </tr>
</table>
</body>
</html>
